Re: [U-Boot-Users] u-boot and OneNAND

2008-07-02 Thread Kyungmin Park
On Thu, Jul 3, 2008 at 1:58 PM, Kyungmin Park <[EMAIL PROTECTED]> wrote:
> Hi,
>
> On Wed, Jul 2, 2008 at 8:55 PM, Mile Davidovic <[EMAIL PROTECTED]> wrote:
>> Hello
>> If I read code correctly u-boot have OneNAND driver. But when I check JFFS2
>> in u-boot it seems that JFFS2 can not work on OneNAND.
>
> Yes, it's not yet implemented.
>

Feel free to use this patch.
the mtdparts and fsload is working, but I'm not suer it's working correctly.

Thank you,
Kyungmin Park
---
-- 
A GNU manual  should give a  good introduction to a beginner reading
through from the start, and should also provide all the details that
hackers want.   --- GNU Coding Standards
--
DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] Flash Initializing problem, porting u-boot-1.1.3 on mpc850

2008-07-02 Thread Detlev Zundel
Hi Li,

> I am try to port u-boot-1.1.3 on a board with the processor MPC850. And i try
> to change the board of TQM850.

Why do you want to port such an old version od U-Boot?  You will not get
much support from this list, as development is only done on the current
versions available from the git repositories.

Also when you switch to a current U-Boot, you will see that also the
TQM850 board switched over to using the CFI driver that very likely also
supports your flash out of the box.

So my suggestion is do not invest time in such an old version, but
restart from current top of tree U-Boot.

Cheers
  Detlev

-- 
An elephant is a mouse with an operating system.
-- Donald Knuth
--
DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] SPAM :(

2008-07-02 Thread Detlev Zundel
Hi,

> Hey, can somebody block this moron somehow? It's getting annoying; it is not
> an occasional spam but regular posting...

I added the e-mail to the blocked addresses.

Cheers
  Detlev

-- 
I just found out that the brain is like a computer.
If that's true, then there really aren't any stupid people.
Just people running Windows.
--
DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] [PATCH] update mvBL-M7 board config

2008-07-02 Thread Andre Schwarz
update mvBL-M7 config file to use UBOOT_VERSION and define
CONFIG_HIGH_BATS.

Signed-off-by: Andre Schwarz <[EMAIL PROTECTED]>
---






MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner
 board/mvblm7/mvblm7.c|2 +-
 include/configs/MVBLM7.h |5 +++--
 2 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/board/mvblm7/mvblm7.c b/board/mvblm7/mvblm7.c
index 41cb39d..3129703 100644
--- a/board/mvblm7/mvblm7.c
+++ b/board/mvblm7/mvblm7.c
@@ -90,7 +90,7 @@ phys_size_t initdram(int board_type)
 
 int checkboard(void)
 {
-   puts("Board: Matrix Vision mvBlueLYNX-M7 " MV_VERSION "\n");
+   puts("Board: Matrix Vision mvBlueLYNX-M7\n");
 
return 0;
 }
diff --git a/include/configs/MVBLM7.h b/include/configs/MVBLM7.h
index 349ca14..50e188f 100644
--- a/include/configs/MVBLM7.h
+++ b/include/configs/MVBLM7.h
@@ -27,7 +27,7 @@
 #ifndef __CONFIG_H
 #define __CONFIG_H
 
-#define MV_VERSION  "v1.0.1"
+#include 
 
 /*
  * High Level Configuration Options
@@ -336,6 +336,7 @@
 #define CFG_HID0_FINAL CFG_HID0_INIT
 
 #define CFG_HID2   HID2_HBE
+#define CONFIG_HIGH_BATS   1
 
 /* DDR  */
 #define CFG_IBAT0L (CFG_SDRAM_BASE | BATL_PP_10 | BATL_MEMCOHERENCE)
@@ -446,7 +447,7 @@
"mv_dtb_addr=" MV_DTB_ADDR "\0" \
"mv_dtb_addr_ram=" MV_DTB_ADDR_RAM "\0" \
"dtb_name=" MV_DTB_NAME "\0"\
-   "mv_version=" MV_VERSION "\0"   \
+   "mv_version=" U_BOOT_VERSION "\0"   \
"dhcp_client_id=" MV_CI "\0"\
"dhcp_vendor-class-identifier=" MV_VCI "\0" \
"netretry=no\0" \
-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Andre Schwarz
Kim Phillips schrieb:
> On Wed, 02 Jul 2008 18:01:01 +0200
> Andre Schwarz <[EMAIL PROTECTED]> wrote:
>
>   
>> this is a fully configured board, i.e. serial# and ethaddr/eth1addr set
>> up correctly.
>>
>> I'll give the bisect a try a soon as there'll be some time.
>>
>> 
> just to clarify, are you using the mainline u-boot.git tree, or
> u-boot-mpc83xx.git?  you should be using the latter until I ask WD to
> pull.  Actually, if you can confirm it corrects your problem, I have no
> reason to delay it further (I was waiting for WD to get back from
> vacation).
>
> Kim
>   
Kim,

I'm running from mainline.
Do you want me to give u-boot-mpc83xx.git a try ?

After all I think the problem is lurking on my hardware/network somewhere.

I need some more time ...


regards,
Andre

MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Kim Phillips
On Wed, 02 Jul 2008 18:01:01 +0200
Andre Schwarz <[EMAIL PROTECTED]> wrote:

> this is a fully configured board, i.e. serial# and ethaddr/eth1addr set
> up correctly.
> 
> I'll give the bisect a try a soon as there'll be some time.
> 
just to clarify, are you using the mainline u-boot.git tree, or
u-boot-mpc83xx.git?  you should be using the latter until I ask WD to
pull.  Actually, if you can confirm it corrects your problem, I have no
reason to delay it further (I was waiting for WD to get back from
vacation).

Kim

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH][resubmit] AX88180: new gigabit network driver

2008-07-02 Thread Ben Warren
Louis wrote:
> Dear Ben,
>
> Thanks for your suggestion; I will correct the driver as soon as 
> possible.
> And I make a mistake in sending the mail through outlook express, 
> hence making indentation problems.
Great!  Thanks Louis.  For sending patches, I highly recommend using 
git-send-email instead of your mail client.  While it's possible to get 
most clients to send properly formatted patches, it often takes a lot of 
trial and error, while git-send-email always works (AFAIK).  Also, 
please consider running 'Lindent -pcs' on the code before sending.  This 
page is very useful:

http://www.denx.de/wiki/UBoot/CodingStyle

regards,
Ben

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] Ethernet support for LAN91C111

2008-07-02 Thread Ben Warren
Shinose wrote:
>
>
> On Tue, Jul 1, 2008 at 7:42 PM, Ben Warren <[EMAIL PROTECTED] 
> > wrote:
>
> Hi Naveen,
>
> On Tue, Jul 1, 2008 at 7:02 AM, navin karnam
> <[EMAIL PROTECTED] > wrote:
> >
> > Hi,
> >
> > I have pxa255 board and one Ethernet controller LAN91C111-Nu
> (10/100 Base T)
> > attached to it.
> > Does u-boot code supports this type of Ethernet controller? Can
> anybody tell
> > what are the changes that need to be done to make this Ethernet
> controller
> > work? If not how do i had the support for it?
> >
>
> I believe the LNA91C111 is software compatible with the LAN91xx, but
> don't know for sure.  If this is true, you should be able to use the
> driver called 'smc9111.c'.  Be sure to get the latest version of the
> code base from git.denx.de .
>
> regards,
> Ben
>
> -
> Check out the new SourceForge.net Marketplace.
> It's the best place to buy or sell services for
> just about anything Open Source.
> http://sourceforge.net/services/buy/index.php
> ___
> U-Boot-Users mailing list
> U-Boot-Users@lists.sourceforge.net
> 
> https://lists.sourceforge.net/lists/listinfo/u-boot-users
>
>
>
> Hi Naveen,
>
> The driver support the SMSC chip 9111 on any platform if you have a 32 
> bit wide databus. For other bus widths you need to customize the driver.
>
The driver supports both 32-bit and 16-bit, and probably 8-bit too, 
although nobody's tried it and reported results.
> Thanks & Regards,
> Shinose.
regards,
Ben

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Jerry Van Baren
Andre Schwarz wrote:
> Jerry,
> 
> I don't understand this.
> 
> The code is far from using the device tree - the dtb is fetched by tftp
> right after bootp.
> 
>  It's the initial bootp/dhcp that doesn't work
> 
> regards,
> Andre

Ah, right, my bad.

Sorry for the noise,
gvb

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Andre Schwarz
Jerry,

I don't understand this.

The code is far from using the device tree - the dtb is fetched by tftp
right after bootp.

 It's the initial bootp/dhcp that doesn't work

regards,
Andre


Jerry Van Baren schrieb:
> Kim Phillips wrote:
>> On Wed, 02 Jul 2008 16:36:11 +0200
>> Andre Schwarz <[EMAIL PROTECTED]> wrote:
>>
>>> Ben,
>>>
>>> thanks for your quick reply.
>>> Looks like you're right - nothing changed regarding network yet.
>>>
>>> Maybe it's a cpu specific problem.
>>> Kim ? Can you help here ?
>>>
>>
>> I know of nothing (barring this being the ETHADDR not specified
>> problem) that could have caused this. Can you try using git-bisect?
>>
>> Kim
>
> Some people were caught by the somewhat recent requirement for an
> /aliases node and properties pointing to the "real" ethernet node
> (which is a Good Thing[tm] because it makes the code board agnostic,
> pushes the board configuration into the .dts where it belongs).
>
> I don't associate Andre's assertion:
>> Obviously the MII interface stopped working, i.e. all reads give 0xFF.
> with the symptoms caused by a missing /aliases node.  Maybe, maybe
> not, could be my lack of experience.
>
> Best regards,
> gvb
>


MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Andre Schwarz
Kim Phillips schrieb:
> On Wed, 02 Jul 2008 16:36:11 +0200
> Andre Schwarz <[EMAIL PROTECTED]> wrote:
>
>   
>> Ben,
>>
>> thanks for your quick reply.
>> Looks like you're right - nothing changed regarding network yet.
>>
>> Maybe it's a cpu specific problem.
>> Kim ? Can you help here ?
>>
>> 
>
> I know of nothing (barring this being the ETHADDR not specified
> problem) that could have caused this. Can you try using git-bisect?
>
> Kim
>   
Kim,

this is a fully configured board, i.e. serial# and ethaddr/eth1addr set
up correctly.

I'll give the bisect a try a soon as there'll be some time.

regards,
Andre

MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Jerry Van Baren
Kim Phillips wrote:
> On Wed, 02 Jul 2008 16:36:11 +0200
> Andre Schwarz <[EMAIL PROTECTED]> wrote:
> 
>> Ben,
>>
>> thanks for your quick reply.
>> Looks like you're right - nothing changed regarding network yet.
>>
>> Maybe it's a cpu specific problem.
>> Kim ? Can you help here ?
>>
> 
> I know of nothing (barring this being the ETHADDR not specified
> problem) that could have caused this. Can you try using git-bisect?
> 
> Kim

Some people were caught by the somewhat recent requirement for an 
/aliases node and properties pointing to the "real" ethernet node (which 
is a Good Thing[tm] because it makes the code board agnostic, pushes the 
board configuration into the .dts where it belongs).

I don't associate Andre's assertion:
> Obviously the MII interface stopped working, i.e. all reads give 0xFF.
with the symptoms caused by a missing /aliases node.  Maybe, maybe not, 
could be my lack of experience.

Best regards,
gvb


-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Kim Phillips
On Wed, 02 Jul 2008 16:36:11 +0200
Andre Schwarz <[EMAIL PROTECTED]> wrote:

> Ben,
> 
> thanks for your quick reply.
> Looks like you're right - nothing changed regarding network yet.
> 
> Maybe it's a cpu specific problem.
> Kim ? Can you help here ?
> 

I know of nothing (barring this being the ETHADDR not specified
problem) that could have caused this. Can you try using git-bisect?

Kim

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH] MPC85xx: correct the procedure to change CCSRBAR.

2008-07-02 Thread Kumar Gala

On Jul 2, 2008, at 9:25 AM, Andrew Klossner wrote:

> The MPC8555E and MPC8548E reference manuals are quite specific about
> the formula required to change the value of CCSRBAR.  This patch
> implements that formula.

Those manuals are not correct in their description of updating CCSRBAR.

The current code meets all the requirements excepting doing a load  
from some other address location.

So you really want:

 temp = in_be32((volatile u32 *)CFG_CCSRBAR_DEFAULT);
 out_be32((volatile u32 *)CFG_CCSRBAR_DEFAULT,  
CFG_CCSRBAR_PHYS >> 12);

/* do a dummy load from somewhere else */
temp = in_be32((volatile u32 *)TEXT_BASE);

 temp = in_be32((volatile u32 *)CFG_CCSRBAR);

The in_be32/out_be32 cover the sync requirements that are needed.

- k

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH] cpu/mpc85xx/start.S: correct temporary TLB

2008-07-02 Thread Kumar Gala

On Jul 2, 2008, at 9:11 AM, Andrew Klossner wrote:

>> From 03e28f90637703aaef9356dc398adedcdf06cb94 Mon Sep 17 00:00:00  
>> 2001
> From: Andrew Klossner <[EMAIL PROTECTED]>
> Date: Wed, 2 Jul 2008 07:03:53 -0700
> Subject: [PATCH] Change the temp map to ROM to align addresses to  
> page size.
>
> With a page size of BOOKE_PAGESZ_16M, both the real and effective
> addresses must be multiples of 16MB.  The hardware silently truncates
> them so the code happens to work.  This patch clarifies the situation
> by establishing addresses that the hardware doesn't need to truncate.
> ---
> cpu/mpc85xx/start.S |8 
> 1 files changed, 4 insertions(+), 4 deletions(-)
>
> diff --git a/cpu/mpc85xx/start.S b/cpu/mpc85xx/start.S
> index 2b5d90e..e2554d7 100644
> --- a/cpu/mpc85xx/start.S
> +++ b/cpu/mpc85xx/start.S
> @@ -188,11 +188,11 @@ _start_e500:
>   lis r7,FSL_BOOKE_MAS1(1, 1, 0, 1, BOOKE_PAGESZ_16M)@h
>   ori r7,r7,FSL_BOOKE_MAS1(1, 1, 0, 1, BOOKE_PAGESZ_16M)@l
>
> - lis r8,FSL_BOOKE_MAS2(TEXT_BASE, (MAS2_I|MAS2_G))@h
> - ori r8,r8,FSL_BOOKE_MAS2(TEXT_BASE, (MAS2_I|MAS2_G))@l
> + lis r8,FSL_BOOKE_MAS2(0xff00, (MAS2_I|MAS2_G))@h
> + ori r8,r8,FSL_BOOKE_MAS2(0xff00, (MAS2_I|MAS2_G))@l

This needs to be TEXT_BASE & 0xFF00

> - lis r9,FSL_BOOKE_MAS3(0xff80, 0, (MAS3_SX|MAS3_SW| 
> MAS3_SR))@h
> - ori r9,r9,FSL_BOOKE_MAS3(0xff80, 0, (MAS3_SX|MAS3_SW| 
> MAS3_SR))@l
> + lis r9,FSL_BOOKE_MAS3(0xff00, 0, (MAS3_SX|MAS3_SW| 
> MAS3_SR))@h
> + ori r9,r9,FSL_BOOKE_MAS3(0xff00, 0, (MAS3_SX|MAS3_SW| 
> MAS3_SR))@l
>
>   mtspr   MAS0,r6
>   mtspr   MAS1,r7

- k

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Andre Schwarz
Ben,

thanks for your quick reply.
Looks like you're right - nothing changed regarding network yet.

Maybe it's a cpu specific problem.
Kim ? Can you help here ?


regards,
Andre

Ben Warren schrieb:
> Hi Andre,
>
> On Wed, Jul 2, 2008 at 7:03 AM, Andre Schwarz
> <[EMAIL PROTECTED]> wrote:
>   
>> Ben,
>>
>> after pulling u-boot today ethernet stopped working on my MPC8343 based
>> board (mvBL-M7).
>> I'm using a Vitesse VSC8601 RGMII phy on TSEC0-1.
>>
>> I know there's some rewriting/clean-up going on ...
>>
>> 
> Yeah, but none of that's in the main source tree.
>
>   
>> What do I have to do to get it working again ?
>> Any new defines introduced lately ?
>>
>> Obviously the MII interface stopped working, i.e. all reads give 0xFF.
>> Switching back to older U-boot (3-4 weeks ago) works fine.
>> 
>
> Looking here:
> http://git.denx.de/?p=u-boot.git;a=history;f=drivers/net/tsec.c;h=6e0f2c6fd081baa19d80a985717d470a1f78bc2d;hb=HEAD
>
> nothing new has been added except support for a new PHY, and that was
> about 5 weeks ago.
>   
>> Any help is welcome.
>>
>> 
> Sorry, I don't have access to my MPC8349 board right now or I'd try to
> help more usefully.  Maybe you can post some more information.
>
>   
>> regards,
>> Andre
>>
>> MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
>> Amtsgericht Stuttgart, HRB 271090
>> Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner
>>
>> 
> regards,
> Ben
>   


MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] Booting Multi Image FIle

2008-07-02 Thread Alemao
My apologies, i was using ramdisk image with some headers... thats why
kernel couldnt find it.

Cheers,

--
Alemao

On Wed, Jul 2, 2008 at 10:04 AM, Alemao <[EMAIL PROTECTED]> wrote:
> Actually i havent read, cause im using u-boot 1.1.14
>
> What im trying to do is using a multi-image file with this version.
>
> If i do:  bootm ${kernel_addr} ${ramdisk_addr} ${fdt_addr}
> everything is OK, the problem for me is getting this addresses, i
> had to browse the image with a hex editor.
>
> If i do: bootm ${kernel_addr}
> the kernel doesnt find ramdisk
>
> So i have to find a way for getting it works using just the command above.
>
> Move to u-boot 1.3.3 is not a good idea right now.
>
> Cheers,
>
> --
> Alemao
>
> On Mon, Jun 30, 2008 at 8:43 AM, Detlev Zundel <[EMAIL PROTECTED]> wrote:
>> Hi Alemao,
>>
>>> bootm ${kernel_addr} ${ramdisk_addr} ${fdt_addr}
>>>
>>> But, is there a way of getting this values instead of searching with a
>>> hexeditor through the image??
>>
>> So you read doc/uImage.FIT/command_syntax_extension.txt containing this
>> example at the end:
>>
>> - boot "[EMAIL PROTECTED]" from a new uImage at 20, with initrd "[EMAIL 
>> PROTECTED]"
>>  and FDT
>>  "[EMAIL PROTECTED]", both stored in some other new uImage located at 80:
>> bootm 20:[EMAIL PROTECTED] 80:[EMAIL PROTECTED] 80:[EMAIL 
>> PROTECTED]
>>
>> And you still have questions? ;)
>>
>> Cheers
>>  Detlev
>>
>> --
>> The proprietary-Unix players proved so ponderous, so blind, and so inept at
>> marketing that Microsoft was able to grab away a large part of their market
>> with the shockingly inferior technology of its Windows operating system.
>>   -- "A Brief History of Hackerdom" by Eric Steven Raymond
>> --
>> DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
>> HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
>> Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]
>>
>

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] [PATCH] MPC85xx: correct the procedure to change CCSRBAR.

2008-07-02 Thread Andrew Klossner
The MPC8555E and MPC8548E reference manuals are quite specific about
the formula required to change the value of CCSRBAR.  This patch
implements that formula.
---
 cpu/mpc85xx/cpu_init.c |   25 +++--
 1 files changed, 23 insertions(+), 2 deletions(-)

diff --git a/cpu/mpc85xx/cpu_init.c b/cpu/mpc85xx/cpu_init.c
index 736aef1..2f256de 100644
--- a/cpu/mpc85xx/cpu_init.c
+++ b/cpu/mpc85xx/cpu_init.c
@@ -141,10 +141,31 @@ void cpu_init_early_f(void)
MAS3_SX|MAS3_SW|MAS3_SR, MAS2_I|MAS2_G,
1, 1, BOOKE_PAGESZ_4K, 0);
 
+   // Update CCSRBAR using the procedure described in
+   // the MPC8548E Reference Manual, section 4.3.1.1.1:
+   // -- Read the current value of CCSRBAR using a load word
+   //instruction followed by an isync.
+   //This forces all accesses to configuration space to
+   //complete.
temp = in_be32((volatile u32 *)CFG_CCSRBAR_DEFAULT);
-   out_be32((volatile u32 *)CFG_CCSRBAR_DEFAULT, CFG_CCSRBAR_PHYS 
>> 12);
-
+   asm volatile ("isync");
+
+   // -- Write the new value to CCSRBAR.
+   out_be32((volatile u32 *)CFG_CCSRBAR_DEFAULT,
+CFG_CCSRBAR_PHYS >> 12);
+
+   // -- Perform a load of an address that does not access
+   //configuration space or the on-chip SRAM,
+   //but has an address mapping already in effect
+   //(for example, boot ROM).
+   //Follow this load with an isync.
+   temp = *(volatile u32 *)0xf000;
+   asm volatile ("isync");
+
+   // -- Read the contents of CCSRBAR from its new location,
+   //followed by another isync.
temp = in_be32((volatile u32 *)CFG_CCSRBAR);
+   asm volatile ("isync");
}
 #endif
 
-- 
1.5.5


-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Ben Warren
Hi Andre,

On Wed, Jul 2, 2008 at 7:03 AM, Andre Schwarz
<[EMAIL PROTECTED]> wrote:
> Ben,
>
> after pulling u-boot today ethernet stopped working on my MPC8343 based
> board (mvBL-M7).
> I'm using a Vitesse VSC8601 RGMII phy on TSEC0-1.
>
> I know there's some rewriting/clean-up going on ...
>
Yeah, but none of that's in the main source tree.

> What do I have to do to get it working again ?
> Any new defines introduced lately ?
>
> Obviously the MII interface stopped working, i.e. all reads give 0xFF.
> Switching back to older U-boot (3-4 weeks ago) works fine.

Looking here:
http://git.denx.de/?p=u-boot.git;a=history;f=drivers/net/tsec.c;h=6e0f2c6fd081baa19d80a985717d470a1f78bc2d;hb=HEAD

nothing new has been added except support for a new PHY, and that was
about 5 weeks ago.
>
> Any help is welcome.
>
Sorry, I don't have access to my MPC8349 board right now or I'd try to
help more usefully.  Maybe you can post some more information.

> regards,
> Andre
>
> MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
> Amtsgericht Stuttgart, HRB 271090
> Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner
>
regards,
Ben

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] [PATCH] Fix printf errors.

2008-07-02 Thread Andrew Klossner
The compiler will help find mismatches between printf formats and
arguments if you let it.  This patch adds the necessary attributes to
declarations in include/common.h, then corrects the resulting compiler
warnings in several files.  Some of these were bugs, e.g., "$d"
instead of "%d" and incorrect arguments in common/cmd_fdt.c.  Others
were just annoying, like int-long mismatches on a system where both
are 32 bits.  It's worth fixing the annoying errors to catch the real
ones.

I can only compile for ppc architecture so have not tested much of the
source code for further warnings.

common/cmd_fdt.c
common/common/main.c
cpu/mpc85xx/traps.c
include/common.h
lib_ppc/bootm.c
net/tftp.c
---
 common/cmd_fdt.c|8 
 common/main.c   |2 +-
 cpu/mpc85xx/traps.c |8 
 include/common.h|   15 ++-
 lib_ppc/bootm.c |8 
 net/tftp.c  |2 +-
 6 files changed, 24 insertions(+), 19 deletions(-)

diff --git a/common/cmd_fdt.c b/common/cmd_fdt.c
index 97b9dd7..d3b19dd 100644
--- a/common/cmd_fdt.c
+++ b/common/cmd_fdt.c
@@ -451,14 +451,14 @@ static int fdt_valid(void)
if (err == -FDT_ERR_BADVERSION) {
if (fdt_version(working_fdt) <
FDT_FIRST_SUPPORTED_VERSION) {
-   printf (" - too old, fdt $d < %d",
+   printf (" - too old, fdt %d < %d",
fdt_version(working_fdt),
FDT_FIRST_SUPPORTED_VERSION);
working_fdt = NULL;
}
if (fdt_last_comp_version(working_fdt) >
FDT_LAST_SUPPORTED_VERSION) {
-   printf (" - too new, fdt $d > %d",
+   printf (" - too new, fdt %d > %d",
fdt_version(working_fdt),
FDT_LAST_SUPPORTED_VERSION);
working_fdt = NULL;
@@ -546,7 +546,7 @@ static int fdt_parse_prop(char **newval, int count, char 
*data, int *len)
newp = newval[++stridx];
}
if (*newp != ']') {
-   printf("Unexpected character '%c'\n", *newval);
+   printf("Unexpected character '%c'\n", *newp);
return 1;
}
} else {
@@ -763,7 +763,7 @@ static int fdt_print(const char *pathp, char *prop, int 
depth)
}
break;
case FDT_NOP:
-   printf("/* NOP */\n", &tabs[MAX_LEVEL - level]);
+   printf("%s/* NOP */\n", &tabs[MAX_LEVEL - level]);
break;
case FDT_END:
return 1;
diff --git a/common/main.c b/common/main.c
index 046da6f..79ad291 100644
--- a/common/main.c
+++ b/common/main.c
@@ -509,7 +509,7 @@ void reset_cmd_timeout(void)
  */
 
 #define putnstr(str,n) do {\
-   printf ("%.*s", n, str);\
+   printf ("%.*s", (int)n, str);   \
} while (0)
 
 #define CTL_CH(c)  ((c) - 'a' + 1)
diff --git a/cpu/mpc85xx/traps.c b/cpu/mpc85xx/traps.c
index fd36658..0eab694 100644
--- a/cpu/mpc85xx/traps.c
+++ b/cpu/mpc85xx/traps.c
@@ -216,10 +216,10 @@ MachineCheckException(struct pt_regs *regs)
 
if (machinecheck_count > 1) {
regs->nip += 4; /* skip offending instruction */
-   printf("Skipping current instr, Returning to 0x%08x\n",
+   printf("Skipping current instr, Returning to 0x%08lx\n",
   regs->nip);
} else {
-   printf("Returning back to 0x%08x\n",regs->nip);
+   printf("Returning back to 0x%08lx\n",regs->nip);
}
 }
 
@@ -302,7 +302,7 @@ ExtIntException(struct pt_regs *regs)
printf("External Interrupt Exception at PC: %lx, SR: %lx, vector=%lx",
   regs->nip, regs->msr, regs->trap);
vect = pic->iack0;
-   printf(" irq [EMAIL PROTECTED]",&pic->iack0,vect);
+   printf(" irq [EMAIL PROTECTED]",(int)&pic->iack0,vect);
show_regs(regs);
print_backtrace((unsigned long *)regs->gpr[1]);
machinecheck_count++;
@@ -310,7 +310,7 @@ ExtIntException(struct pt_regs *regs)
printf("Returning back to 0x%08x\n",regs->nip);
 #else
regs->nip += 4; /* skip offending instruction */
-   printf("Skipping current instr, Returning to 0x%08x\n",regs->nip);
+   printf("Skipping current instr, Returning to 0x%08lx\n",regs->nip);
 #endif
 
 }
diff --git a/include/common.h b/include/common.h
index fd5adb3..51c2be8 100644
--- a/include/common.h
+++ b/include/common.h
@@ -607,8 +607,10 @@ ulong  simple_strtoul(const char *cp,char 
**endp,unsigned int base);
 unsigned long long

[U-Boot-Users] [PATCH] cpu/mpc85xx/start.S: correct temporary TLB

2008-07-02 Thread Andrew Klossner
>From 03e28f90637703aaef9356dc398adedcdf06cb94 Mon Sep 17 00:00:00 2001
From: Andrew Klossner <[EMAIL PROTECTED]>
Date: Wed, 2 Jul 2008 07:03:53 -0700
Subject: [PATCH] Change the temp map to ROM to align addresses to page size.

With a page size of BOOKE_PAGESZ_16M, both the real and effective
addresses must be multiples of 16MB.  The hardware silently truncates
them so the code happens to work.  This patch clarifies the situation
by establishing addresses that the hardware doesn't need to truncate.
---
 cpu/mpc85xx/start.S |8 
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/cpu/mpc85xx/start.S b/cpu/mpc85xx/start.S
index 2b5d90e..e2554d7 100644
--- a/cpu/mpc85xx/start.S
+++ b/cpu/mpc85xx/start.S
@@ -188,11 +188,11 @@ _start_e500:
lis r7,FSL_BOOKE_MAS1(1, 1, 0, 1, BOOKE_PAGESZ_16M)@h
ori r7,r7,FSL_BOOKE_MAS1(1, 1, 0, 1, BOOKE_PAGESZ_16M)@l
 
-   lis r8,FSL_BOOKE_MAS2(TEXT_BASE, (MAS2_I|MAS2_G))@h
-   ori r8,r8,FSL_BOOKE_MAS2(TEXT_BASE, (MAS2_I|MAS2_G))@l
+   lis r8,FSL_BOOKE_MAS2(0xff00, (MAS2_I|MAS2_G))@h
+   ori r8,r8,FSL_BOOKE_MAS2(0xff00, (MAS2_I|MAS2_G))@l
 
-   lis r9,FSL_BOOKE_MAS3(0xff80, 0, (MAS3_SX|MAS3_SW|MAS3_SR))@h
-   ori r9,r9,FSL_BOOKE_MAS3(0xff80, 0, (MAS3_SX|MAS3_SW|MAS3_SR))@l
+   lis r9,FSL_BOOKE_MAS3(0xff00, 0, (MAS3_SX|MAS3_SW|MAS3_SR))@h
+   ori r9,r9,FSL_BOOKE_MAS3(0xff00, 0, (MAS3_SX|MAS3_SW|MAS3_SR))@l
 
mtspr   MAS0,r6
mtspr   MAS1,r7
diff --git a/common/cmd_jffs2.c b/common/cmd_jffs2.c
index 1b67e73..51c742c 100644
--- a/common/cmd_jffs2.c
+++ b/common/cmd_jffs2.c
@@ -51,7 +51,7 @@
  * mtdids=[,,...]
  *
  * := =
- *:= 'nand'|'nor'
+ *:= 'nand'|'nor'|'onenand'
  *   := mtd device number, 0...
  *:= unique device tag used by linux kernel to find mtd
device (mtd->name)
  *
@@ -103,9 +103,17 @@
 #include 
 #endif /* !CFG_NAND_LEGACY */
 #endif
+
+#if defined(CONFIG_CMD_ONENAND)
+#include 
+#include 
+
+extern struct mtd_info onenand_mtd;
+#endif
+
 /* enable/disable debugging messages */
 #defineDEBUG_JFFS
-#undef DEBUG_JFFS
+//#undef   DEBUG_JFFS

 #ifdef  DEBUG_JFFS
 # define DEBUGF(fmt, args...)  printf(fmt ,##args)
@@ -401,6 +409,42 @@ static int part_validate_nand(struct mtdids *id,
struct part_info *part)
 }

 /**
+ * Performs sanity check for supplied OneNAND flash partition.
+ * Table of existing OneNAND flash devices is searched and partition device
+ * is located. Alignment with the granularity of nand erasesize is verified.
+ *
+ * @param id of the parent device
+ * @param part partition to validate
+ * @return 0 if partition is valid, 1 otherwise
+ */
+static int part_validate_onenand(struct mtdids *id, struct part_info *part)
+{
+#if defined(CONFIG_CMD_ONENAND)
+   /* info for OneNAND chips */
+   struct mtd_info *mtd;
+
+   mtd = &onenand_mtd;
+
+   if ((unsigned long)(part->offset) % mtd->erasesize) {
+   printf("%s%d: partition (%s) start offset alignment 
incorrect\n",
+   MTD_DEV_TYPE(id->type), id->num, part->name);
+   return 1;
+   }
+
+   if (part->size % mtd->erasesize) {
+   printf("%s%d: partition (%s) size alignment incorrect\n",
+   MTD_DEV_TYPE(id->type), id->num, part->name);
+   return 1;
+   }
+
+   return 0;
+#else
+   return 1;
+#endif
+}
+
+
+/**
  * Performs sanity check for supplied partition. Offset and size are verified
  * to be within valid range. Partition type is checked and either
  * parts_validate_nor() or parts_validate_nand() is called with the argument
@@ -436,6 +480,8 @@ static int part_validate(struct mtdids *id, struct
part_info *part)
return part_validate_nand(id, part);
else if (id->type == MTD_DEV_TYPE_NOR)
return part_validate_nor(id, part);
+   else if (id->type == MTD_DEV_TYPE_ONENAND)
+   return part_validate_onenand(id, part);
else
DEBUGF("part_validate: invalid dev type\n");

@@ -755,7 +801,16 @@ static int device_validate(u8 type, u8 num, u32 *size)
 #else
printf("support for NAND devices not present\n");
 #endif
-   }
+   } else if (type == MTD_DEV_TYPE_ONENAND) {
+#if defined(CONFIG_CMD_ONENAND)
+   *size = onenand_mtd.size;
+   printk("%s[%d] size %d\n", __func__, __LINE__, *size);
+   return 0;
+#else
+   printf("support for OneNAND devices not present\n");
+#endif
+   } else
+   printf("Unknown defice type %d\n", type);

return 1;
 }
@@ -1065,8 +1120,8 @@ static struct mtdids* id_find_by_mtd_id(const
char *mtd_id, unsigned int mtd_id_
 #endif /* #ifdef CONFIG_JFFS2_CMDLINE */

 /**
  * Parse device id string  := 'nand'|'nor', return device
  * type and number.
  *
  * @param id string describing device id
  * @param ret_id output pointer to next char after parse completes (output)
@@ -1085,6 +1140,9 @@ int id_parse(const char *id, const char
**ret_id, u8 *dev_type, u8 *dev_num)
} else if (strncmp(p, "nor", 3) == 0) {
*dev_type = MTD_DEV_TYPE_NOR;
p += 3;
+   } else if (strncmp(p, "onenand", 7) == 0) {
+   *dev_type = MTD_DEV_TYPE_ONENAND;
+   p += 7;
} else {
printf("incorrect device type in %s\n", id);
return 1;
@@ -1489,7 +1547,7 @@ static int parse_mtdids(const char *const ids)
while(p && (*p != '\0')) {

ret = 1;
-   /* parse 'nor'|'nand' */
+   /* parse 'nor'|'nand'|'onenand' */
if (id_parse(p, &p, &type, &num) != 0)
break;

@@ -1503,6 +1561,7 @@ static int parse_mtdids(const char *const ids)
if (device_validate(type, num, &size) != 0)
return 1

[U-Boot-Users] (no subject)

2008-07-02 Thread 钟文辉
各位老总:您们好!

诚祝:您们在2008年里;有鼠不尽的快乐!鼠不尽的收获!鼠不尽的钞票!
 
鼠不尽的幸福!鼠不尽的美满生活!愿: 您们阖家欢乐!幸福安康!

我公司可以长期提供:出口报关单,核销单,等等一系列手续;代理:出口

报关,商检,境内外运输..等等;还可以代办:出口欧盟许可证,欧盟产地证;

并且还有(广州国际贸易交易会)的摊位可以转让;价格特别优惠;有意者请来邮件

或来电联系。谢谢合作!
 
  电话:0755-81153047。
 
  传真:0755-81172940。
 
  手机:15817477278。
 
  联系人:钟文辉。
 
   
  电子邮箱:[EMAIL PROTECTED]  


此致:
 

敬礼!

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] u-boot and OneNAND

2008-07-02 Thread Kyungmin Park
Hi,

On Wed, Jul 2, 2008 at 8:55 PM, Mile Davidovic <[EMAIL PROTECTED]> wrote:
> Hello
> If I read code correctly u-boot have OneNAND driver. But when I check JFFS2
> in u-boot it seems that JFFS2 can not work on OneNAND.

Yes, it's not yet implemented.

>
> What is proposed way of working with OneNAND and u-boot? Do we have some
> support for bad block management?

Now there's no proper method on OneNAND in open source. but some time
later, the UBI is candidate. If UBI is introduced to u-boot.

Thank you,
Kyungmin Park

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] (no subject)

2008-07-02 Thread 钟文辉
各位老总:您们好!

诚祝:您们在2008年里;有鼠不尽的快乐!鼠不尽的收获!鼠不尽的钞票!
 
鼠不尽的幸福!鼠不尽的美满生活!愿: 您们阖家欢乐!幸福安康!

我公司可以长期提供:出口报关单,核销单,等等一系列手续;代理:出口

报关,商检,境内外运输..等等;还可以代办:出口欧盟许可证,欧盟产地证;

并且还有(广州国际贸易交易会)的摊位可以转让;价格特别优惠;有意者请来邮件

或来电联系。谢谢合作!
 
  电话:0755-81153047。
 
  传真:0755-81172940。
 
  手机:15817477278。
 
  联系人:钟文辉。
 
   
  电子邮箱:[EMAIL PROTECTED]  


此致:
 

敬礼!

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH] Fix printf errors.

2008-07-02 Thread Jerry Van Baren
Andrew Klossner wrote:
> The compiler will help find mismatches between printf formats and
> arguments if you let it.  This patch adds the necessary attributes to
> declarations in include/common.h, then corrects the resulting compiler
> warnings in several files.  Some of these were bugs, e.g., "$d"
> instead of "%d" and incorrect arguments in common/cmd_fdt.c.  Others
> were just annoying, like int-long mismatches on a system where both
> are 32 bits.  It's worth fixing the annoying errors to catch the real
> ones.
> 
> I can only compile for ppc architecture so have not tested much of the
> source code for further warnings.
> 
> common/cmd_fdt.c

cmd_fdt.c portion...
Acked-by: Gerald Van Baren <[EMAIL PROTECTED]>

I'm embarrassed by the number of bugs I wrote into that function and 
apologize for being so sloppy.  My thanks to Andrew and others for 
finding and fixing my screwups.  :-(

Best regards,
gvb


-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] SPAM :(

2008-07-02 Thread ksi
On Wed, 2 Jul 2008, Detlev Zundel wrote:

Thanks.

> Hi,
>
>> Hey, can somebody block this moron somehow? It's getting annoying; it
> is not
>> an occasional spam but regular posting...
>
> I added the e-mail to the blocked addresses.
>
> Cheers
>  Detlev
>
> -- 
> I just found out that the brain is like a computer.
> If that's true, then there really aren't any stupid people.
> Just people running Windows.
> --
> DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
> HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
> Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]
>

---
**
*  [EMAIL PROTECTED]KOI8 Net  < >  The impossible we do immediately.  *
*  Las Vegas   NV, USA   < >  Miracles require 24-hour notice.   *
**

-
@@ -1065,8 +1120,8 @@ static struct mtdids* id_find_by_mtd_id(const

 /**
- * Parse device id string  := 'nand'|'nor', return device
- * type and number.
+ * Parse device id string  := 'nand'|'nor'|'onenand',
+ * return device type and number.
  *
  * @param id string describing device id
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] kernel stopping

2008-07-02 Thread Detlev Zundel
Hi Kishore,

>   Iam working on ARM samsung board SMDK2440 my kernel is stopping
> after seeing the information "Starting kernel ...\n\n" this string is 
> their
> in my lib_arm/Armlinux.c file .
> can anybody help me to know how to proceed next step,

When you have cross checked that you really pass the correct argument
for the console for the kernel to use ("console=...") and it still does
not work, get out your JTAG debugger and debug it.

Cheers
  Detlev

-- 
1.5.5


-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] TSEC/PHY @ MPC834x stopped working

2008-07-02 Thread Andre Schwarz
Ben,

after pulling u-boot today ethernet stopped working on my MPC8343 based
board (mvBL-M7).
I'm using a Vitesse VSC8601 RGMII phy on TSEC0-1.

I know there's some rewriting/clean-up going on ...

What do I have to do to get it working again ?
Any new defines introduced lately ?

Obviously the MII interface stopped working, i.e. all reads give 0xFF.
Switching back to older U-boot (3-4 weeks ago) works fine.

Any help is welcome.

regards,
Andre

MATRIX VISION GmbH, Talstraße 16, DE-71570 Oppenweiler  - Registergericht: 
Amtsgericht Stuttgart, HRB 271090
Geschäftsführer: Gerhard Thullner, Werner Armingeon, Uwe Furtner

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] (no subject)

2008-07-02 Thread 钟文辉
各位老总:您们好!

诚祝:您们在2008年里;有鼠不尽的快乐!鼠不尽的收获!鼠不尽的钞票!
 
鼠不尽的幸福!鼠不尽的美满生活!愿: 您们阖家欢乐!幸福安康!

我公司可以长期提供:出口报关单,核销单,等等一系列手续;代理:出口

报关,商检,境内外运输..等等;还可以代办:出口欧盟许可证,欧盟产地证;

并且还有(广州国际贸易交易会)的摊位可以转让;价格特别优惠;有意者请来邮件

或来电联系。谢谢合作!
 
  电话:0755-81153047。
 
  传真:0755-81172940。
 
  手机:15817477278。
 
  联系人:钟文辉。
 
   
  电子邮箱:[EMAIL PROTECTED]  


此致:
 

敬礼!

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] Re: Booting Multi Image FIle

2008-07-02 Thread Alemao
Actually i havent read, cause im using u-boot 1.1.14

What im trying to do is using a multi-image file with this version.

If i do:  bootm ${kernel_addr} ${ramdisk_addr} ${fdt_addr}
everything is OK, the problem for me is getting this addresses, i
had to browse the image with a hex editor.

If i do: bootm ${kernel_addr}
the kernel doesnt find ramdisk

So i have to find a way for getting it works using just the command above.

Move to u-boot 1.3.3 is not a good idea right now.

Cheers,

--
Alemao

On Mon, Jun 30, 2008 at 8:43 AM, Detlev Zundel <[EMAIL PROTECTED]> wrote:
> Hi Alemao,
>
>> bootm ${kernel_addr} ${ramdisk_addr} ${fdt_addr}
>>
>> But, is there a way of getting this values instead of searching with a
>> hexeditor through the image??
>
> So you read doc/uImage.FIT/command_syntax_extension.txt containing this
> example at the end:
>
> - boot "[EMAIL PROTECTED]" from a new uImage at 20, with initrd "[EMAIL 
> PROTECTED]"
>  and FDT
>  "[EMAIL PROTECTED]", both stored in some other new uImage located at 80:
> bootm 20:[EMAIL PROTECTED] 80:[EMAIL PROTECTED] 80:[EMAIL 
> PROTECTED]
>
> And you still have questions? ;)
>
> Cheers
>  Detlev
>
> --
> The proprietary-Unix players proved so ponderous, so blind, and so inept at
> marketing that Microsoft was able to grab away a large part of their market
> with the shockingly inferior technology of its Windows operating system.
>   -- "A Brief History of Hackerdom" by Eric Steven Raymond
> --
> DENX Software Engineering GmbH,  MD: Wolfgang Denk & Detlev Zundel
> HRB 165235 Munich,  Office: Kirchenstr.5, D-82194 Groebenzell, Germany
> Phone: (+49)-8142-66989-40 Fax: (+49)-8142-66989-80 Email: [EMAIL PROTECTED]
>

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] formalisms dishonors

2008-07-02 Thread Matkowski Kyles
Ahn nyeong,

http://7z.timebetter.cn   

You're not making love to he was not joking but been concealed
in the belt of trees, and that larger body of water. On
the sandy point jutting and a large iron ring with small
clips for caps. Else fails, music reniains. His hand ran
lovingly saw a good deal of my cousin philip says frankly
humorous, is not of the kind to admit of such gently dripping
from the pumpthat was the only.
-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] u-boot and OneNAND

2008-07-02 Thread Mile Davidovic
Hello
If I read code correctly u-boot have OneNAND driver. But when I check JFFS2
in u-boot it seems that JFFS2 can not work on OneNAND.

What is proposed way of working with OneNAND and u-boot? Do we have some
support for bad block management?

Thanks in advace
Mile
-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH][resubmit] AX88180: new gigabit network driver

2008-07-02 Thread Louis
Dear Ben,

Thanks for your suggestion; I will correct the driver as soon as possible.
And I make a mistake in sending the mail through outlook express, hence making 
indentation problems.

- Original Message - 
From: "Ben Warren" <[EMAIL PROTECTED]>
To: "Ben Warren" <[EMAIL PROTECTED]>
Cc: "Louis" <[EMAIL PROTECTED]>; ; "[???]"" 
<[EMAIL PROTECTED]>; ""ASIX [EMAIL PROTECTED]" 
<[EMAIL PROTECTED]>
Sent: Wednesday, July 02, 2008 3:49 PM
Subject: Re: [U-Boot-Users] [PATCH][resubmit] AX88180: new gigabit network 
driver


> On Wed, Jul 2, 2008 at 12:07 AM, Ben Warren <[EMAIL PROTECTED]> wrote:
> 
>
>>> +#define WRITE_TXBUF(data) \
>>> + do { \
>>> +  *(volatile unsigned short *)(AX88180_BASE + TXBUFFER_START) \
>>> +  = data; \
>>> + } while (0)
>>> +
>> In this case, the do{...}while(0) is unnecessary.  Just make the
>> assignment.
>
> Sorry, I was wrong in this case - do{...}while(0) is correct.  Please
> consider replacing all of these macros with static inline functions
> though.  Much easier for everybody that way.
>
> regards,
> Ben
> 



-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


[U-Boot-Users] (no subject)

2008-07-02 Thread Shreeram
Hi

I am using a MPC8349 based board. I have ported the U-boot-1.3.2. When i
transfer some files using the TFTP command the board hangs. Please find
the attached console output. However if i enable ET_DEBUG its getting
through and also tftp transfer is successful from the kernel. Are there
any fixes available for TSEC.








Regards,
R.S.Shree Ram
GDA Technologies,
L&T infotech Park,
Mt.Ponamalle Road,
Manapakkam,
Chennai-600089

U-Boot  1.3.2-g53aaa00b-dirty   (Jun27  2008-   11:00:52)   
MPC83XX

Reset   Status:

CPU:e300c1, MPC8349E,   Rev:31  at  528 MHz,CSB:
264 MHz
Board:  ATCA_OLT
UPMA:   Configured  for TeknovusOLT
I2C:ready
DRAM:   256 MB  (DDR2,  64-bit, ECC off)
FLASH:  8   MB
In: serial
Out:serial
Err:serial
Net:TSEC0,  TSEC1

Type"runflash_nfs"  to  mount   rootfilesystem  over
NFS

Hit any key to  stopautoboot:   0
atcaolt=>
atcaolt=>   setenv  ipaddr  172.29.38.217
atcaolt=>   ping172.29.38.1
Speed:  100,fullduplex
Using   TSEC0   device
host172.29.38.1 is  alive
atcaolt=>   tftp0x20tmrnd/u-boot.bin
Speed:  100,fullduplex
Using   TSEC0   device
TFTPfromserver  172.29.38.7;our IP  address is  
172.29.38.217
Filename'tmrnd/u-boot.bin'.
Loadaddress:0x20
Loading:##-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] CPU (405ep) clock upgrade..

2008-07-02 Thread Stefan Roese
On Wednesday 02 July 2008, Yi-Neng Lin wrote:
>  This arises another question. Assume that both configurations (CPU and
> SDRAM) are obtained from the EEPROM, how can C program/function be adopted
> to use these parameters before CPU/memory is initiated? C
> programs/functions need memory space to setup the stacks, which means
> CPU/memory initialization should be done (via assembly) before any C
> programs/functions can be used.

All this is already taken care of. U-Boot uses a small area for initial RAM. 
Sometimes in D-cache, sometimes in onboard SRAM (SoC). IIRC, the 405EP has 
OCM, so this could be used here. You just need to configure this correctly in 
your board config file. Again I suggest you take a look at the zeus board as 
an example.

Best regards,
Stefan

=
DENX Software Engineering GmbH, MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: +49-8142-66989-0 Fax: +49-8142-66989-80  Email: [EMAIL PROTECTED]
=

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] CPU (405ep) clock upgrade..

2008-07-02 Thread Yi-Neng Lin




Dear Stefan,

  
The CPU and bus related info is hard-coded in the code. This is what I saw
from my code. Not very sure of it, though.

  
  Yes, could be that you are using the fixed, compiled-in speed configuration.
  

This arises another question. Assume that both configurations (CPU and
SDRAM) are obtained from the EEPROM, how can C program/function be
adopted to use these parameters before CPU/memory is initiated? C
programs/functions need memory space to setup the stacks, which means
CPU/memory initialization should be done (via assembly) before any C
programs/functions can be used. 

Thanks again for your answering.

Yi-Neng

  
  
   I think it's the spd_sdram() [cpu/ppc4xx] who does the job, which could
have been an outdated method.

  
  
It was renamed and is now called 40x_spd_sdram.c. For board with DIMM modules 
on 405EP this is the way to go.

  
  
The timing info is read from the SPD (Serial 
Presence Detect) EEPROM on the SDRAM module. My question is, with the
upgraded CPU clock (333MHz), ordinary SDRAMs (PC100 and PC133) may not be
able to support it, which means I may have to use PC2700 (333MHz; too
fast?) or PC66(66MHz; too slow?). Am I correct? Any other comment or
solution for this?

  
  
I'm pretty sure that you still can use the "ordinary" DIMMs. The driver should 
configure the needed parameters like CAS latency accordingly.

Best regards,
Stefan

=
DENX Software Engineering GmbH, MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: +49-8142-66989-0 Fax: +49-8142-66989-80  Email: [EMAIL PROTECTED]
=


  





-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] Ethernet support for LAN91C111

2008-07-02 Thread Shinose
On Tue, Jul 1, 2008 at 7:42 PM, Ben Warren <[EMAIL PROTECTED]>
wrote:

> Hi Naveen,
>
> On Tue, Jul 1, 2008 at 7:02 AM, navin karnam <[EMAIL PROTECTED]>
> wrote:
> >
> > Hi,
> >
> > I have pxa255 board and one Ethernet controller LAN91C111-Nu (10/100 Base
> T)
> > attached to it.
> > Does u-boot code supports this type of Ethernet controller? Can anybody
> tell
> > what are the changes that need to be done to make this Ethernet
> controller
> > work? If not how do i had the support for it?
> >
>
> I believe the LNA91C111 is software compatible with the LAN91xx, but
> don't know for sure.  If this is true, you should be able to use the
> driver called 'smc9111.c'.  Be sure to get the latest version of the
> code base from git.denx.de.
>
> regards,
> Ben
>
> -
> Check out the new SourceForge.net Marketplace.
> It's the best place to buy or sell services for
> just about anything Open Source.
> http://sourceforge.net/services/buy/index.php
> ___
> U-Boot-Users mailing list
> U-Boot-Users@lists.sourceforge.net
> https://lists.sourceforge.net/lists/listinfo/u-boot-users
>


Hi Naveen,

The driver support the SMSC chip 9111 on any platform if you have a 32 bit
wide databus. For other bus widths you need to customize the driver.

Thanks & Regards,
Shinose.
-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH][resubmit] AX88180: new gigabit network driver

2008-07-02 Thread Ben Warren
On Wed, Jul 2, 2008 at 12:07 AM, Ben Warren <[EMAIL PROTECTED]> wrote:


>> +#define WRITE_TXBUF(data) \
>> + do { \
>> +  *(volatile unsigned short *)(AX88180_BASE + TXBUFFER_START) \
>> +  = data; \
>> + } while (0)
>> +
> In this case, the do{...}while(0) is unnecessary.  Just make the
> assignment.

Sorry, I was wrong in this case - do{...}while(0) is correct.  Please
consider replacing all of these macros with static inline functions
though.  Much easier for everybody that way.

regards,
Ben

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH] Fix dm9000 receive status and len little endian issue

2008-07-02 Thread Ben Warren
Tsi-Chung Liew wrote:
> From: TsiChung Liew <[EMAIL PROTECTED]>
> z
> The received status and len was in little endian
> format and caused the ethernet unable to proceed
> further. Add __le16_to_cpu() in dm9000_rx_status_8/16/32bit().
>
> Signed-off-by: TsiChung Liew <[EMAIL PROTECTED]>
>   
Applied to 'next' branch of net repo.

thanks,
Ben

-
Sponsored by: SourceForge.net Community Choice Awards: VOTE NOW!
Studies have shown that voting for your favorite open source project,
along with a healthy diet, reduces your potential for chronic lameness
and boredom. Vote Now at http://www.sourceforge.net/community/cca08
___
U-Boot-Users mailing list
U-Boot-Users@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/u-boot-users


Re: [U-Boot-Users] [PATCH][resubmit] AX88180: new gigabit network driver

2008-07-02 Thread Ben Warren
Louis,

This submission has several style issues.  I suggest you read this:
http://www.denx.de/wiki/UBoot/CodingStyle

Louis wrote:
> Resubmit the driver for the ASIX AX88180 gigabit ethernet chip.
>
> Signed-off-by: Louis Su [EMAIL PROTECTED]
> ---
> drivers/net/Makefile  |1 +
> drivers/net/ax88180.c |  842 
> +
> drivers/net/ax88180.h |  415 
> 3 files changed, 1258 insertions(+), 0 deletions(-)
> create mode 100644 drivers/net/ax88180.c
> create mode 100644 drivers/net/ax88180.h
>
> diff --git a/drivers/net/Makefile b/drivers/net/Makefile
> index 84be288..3a574e0 100644
> --- a/drivers/net/Makefile
> +++ b/drivers/net/Makefile
> @@ -26,6 +26,7 @@ include $(TOPDIR)/config.mk
> LIB := $(obj)libnet.a
>
> COBJS-$(CONFIG_DRIVER_3C589) += 3c589.o
> +COBJS-$(CONFIG_DRIVER_AX88180) += ax88180.o
> COBJS-$(CONFIG_BCM570x) += bcm570x.o bcm570x_autoneg.o 5701rls.o
> COBJS-$(CONFIG_BFIN_MAC) += bfin_mac.o
> COBJS-$(CONFIG_DRIVER_CS8900) += cs8900.o
> diff --git a/drivers/net/ax88180.c b/drivers/net/ax88180.c
> new file mode 100644
> index 000..5579ef0
> --- /dev/null
> +++ b/drivers/net/ax88180.c
> @@ -0,0 +1,842 @@
> +/* ax88180: ASIX AX88180 Non-PCI Gigabit Ethernet u-boot driver */
> +/*
Multi-line comments are done like:

/*
* Comment
*/
> + This program is free software; you can distribute it and/or modify
> + it under the terms of the GNU General Public License (Version 2) as
> + published by the Free Software Foundation.
> + This program is distributed in the hope it will be useful, but
> + WITHOUT ANY WARRANTY; without even the implied warranty of
> + MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
> + General Public License for more details.
> + You should have received a copy of the GNU General Public License
> + along with this program; if not, write to the Free Software
> + Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
> + USA.
> +*/
> +
> +/*
> + 
> 
> + ASIX AX88180 Non-PCI 16/32-bit Gigabit Ethernet Linux Driver
> +
> + The AX88180 Ethernet controller is a high performance and highly
> + integrated local CPU bus Ethernet controller with embedded 40K bytes
> + SRAM and supports both 16-bit and 32-bit SRAM-Like interfaces for any
> + embedded systems.
> + The AX88180 is a single chip 10/100/1000Mbps Gigabit Ethernet
> + controller that supports both MII and RGMII interfaces and is
> + compliant to IEEE 802.3, IEEE 802.3u and IEEE 802.3z standards.
> +
> + Please visit ASIX's web site (http://www.asix.com.tw) for more
> + details.
> +
> + Module Name : ax88180.c
> + Date  : 2008-07-01
> + History
> + 09/06/2006 : New release for AX88180 US2 chip.
> + 07/01/2008 : Fix up the coding style and using functions
> +instead of most macros
> + 
> 
> +*/
> +#include 
> +#include 
> +#include 
> +
> +#include "ax88180.h"
> +
> +#ifdef CONFIG_DRIVER_AX88180
This is unnecessary.  You're already compiling conditionally in Makefile
> +
> +/*
> +=== 
>
> +<<  Local SubProgram Declaration  >>
> +=== 
>
> +*/
> +static void ax88180_rx_handler (void);
> +static int ax88180_PHY_initial (void);
> +static void ax88180_meida_config (void);
> +static unsigned long get_CicadaPHY_meida_mode (void);
> +static unsigned long get_MarvellPHY_meida_mode (void);
> +static unsigned short ax88180_mdio_read (unsigned long phyaddr,
> + unsigned long regaddr);
Indentation with TABs, 8 characters wide.
> +static void ax88180_mdio_write (unsigned long phyaddr,
> +  unsigned long regaddr,
> +  unsigned short regdata);
> +
> +/*
> +=== 
>
> +<<  Declare Macro/Structure Definition  >>
> +=== 
>
> +*/
> +typedef enum _AX88180_LINK_STATE {
> + INS_LINK_DOWN,
> + INS_LINK_UP,
> + INS_LINK_UNKNOWN
> +} AX88180_LINK_STATE;
> +
Again, serious indentation problems.  I won't mention it again.
> +typedef struct _AX88180_PRIVATE {
> + unsigned long PhyAddr;
> + unsigned long PhyID0;
> + unsigned long FirstTxDesc;
> + unsigned long NextTxDesc;
> + unsigned long rxbuf_overflow_count;
> + AX88180_LINK_STATE LinkState;
> +} AX88180_PRIVATE;
> +
> +AX88180_PRIVATE axlocal;
> +
> +#if (DEBUG_FLAGS & DEBUG_MSG)
> +static inline void ax88180_disp_all_reg (void)
> +{
> + unsigned long tmpval;
> + int i;
> + PRINTK (DEBUG_MSG, "ax88180: AX88180 MAC Registers:\n");
We don't need yet another way to print debug information.  Please use 
debug() or printf() only.
> + for (i = 0xFC00; i <= 0xFCFF; i += 4) {
> +  READ_MACREG (i, tmpval);
> +  PRINTK (DEBUG_MSG, "0x%04x=0x%08lx ", i, tmpval